"""
EbookTranslator - 世界上性能最高的电子书保留布局翻译库
 The world's highest performing e-book retention layout translation library
"""

__version__ = '0.1.0'

from .main_function import main_function

# 导出主要类和函数
__all__ = ['main_function']
